import { Component, OnInit, OnDestroy, Inject } from '@angular/core';
import { Editor } from 'ngx-editor';
import { DateAdapter } from '@angular/material/core';
import { JournalEntry } from 'src/interfaces/interfaces';
import localeDe from '@angular/common/locales/de';
import { registerLocaleData } from '@angular/common';

@Component({
  selector: 'app-journal-notes',
  templateUrl: './journal-notes.component.html',
  styleUrl: './journal-notes.component.scss',
})
export class JournalNotesComponent implements OnInit, OnDestroy {
  editor: Editor = new Editor();
  html = '';
  isInEditMode = true;
  currentEntryIndex: number = 0;
  isNewEntry = false;

  public entries: JournalEntry[] = [
    {
      title: 'testtitle',
      content: 'testcontent',
      created: new Date(2024, 8, 29),
    },
    {
      title: 'zweiter titel',
      content: 'zweiter content',
      created: new Date(2023, 1, 2),
    },
  ];
  currentEntry: JournalEntry = this.entries[this.currentEntryIndex];

  toolbar: any = [
    // default value
    ['bold', 'italic'],
    ['bullet_list'],
    [{ heading: ['h3', 'h4', 'h5', 'h6'] }],
  ];

  constructor(private _adapter: DateAdapter<any>) {
    registerLocaleData(localeDe);
  }

  ngOnInit(): void {
    this._adapter.setLocale('de');
  }

  // make sure to destory the editor
  ngOnDestroy(): void {
    this.editor.destroy();
  }

  public activateEntry(index: number): void {
    this.currentEntryIndex = index;
    this.currentEntry = this.entries[index];
    this.isInEditMode = false;
  }

  addEntry(): void {
    this.currentEntry = {
      title: '',
      content: '',
      created: new Date(),
    };
    this.isNewEntry = true;
    this.isInEditMode = true;
    // Hightlight no entry
    this.currentEntryIndex = -1;
  }

  public saveEntry(): void {
    if (this.isNewEntry) {
      // Prepend the new JournalEntry
      this.entries = [this.currentEntry, ...this.entries];
      this.isNewEntry = false;
      this.currentEntryIndex = 0;
    }
    this.isInEditMode = false;
  }

  public discardEntry(): void {
    if (this.isNewEntry) {
      // this.currentEntryIndex = this.entries.length - 1;
      this.isNewEntry = false;
    }
    this.currentEntry = this.entries[this.currentEntryIndex];
    this.isInEditMode = false;
  }

  deleteEntry(): void {
    this.entries.splice(this.currentEntryIndex, 1);
    if (this.entries.length === 0) {
      this.currentEntryIndex = -1;
    } else {
      this.currentEntryIndex = Math.max(this.currentEntryIndex - 1, 0);
      this.currentEntry = this.entries[this.currentEntryIndex];
    }
  }
}
